==================================================
``psyclone.tests.psyir.backend.sympy_writer_test``
==================================================

.. automodule:: psyclone.tests.psyir.backend.sympy_writer_test

   .. contents::
      :local:

.. currentmodule:: psyclone.tests.psyir.backend.sympy_writer_test
